@@ -1,11 +1,10 @@
-
 import pytest
 from digital_multimeter import DigitalMultimeter
 
 
 def test_default_model():
     dm = DigitalMultimeter.DigitalMultimeter()
-    assert dm.model == 'Default'
+    assert dm.model == "Default"
 
 
 def test_default_multimeter():
@@ -16,6 +15,6 @@ def test_default_multimeter():
 def test_default_models():
     dm = DigitalMultimeter.DigitalMultimeter()
     assert type(dm.get_models_supported()) is dict
-    assert 'models' in dm.get_models_supported().keys()
-    assert type(dm.get_models_supported()['models']) is list
-    assert 'Default' in dm.get_models_supported()['models']
+    assert "models" in dm.get_models_supported().keys()
+    assert type(dm.get_models_supported()["models"]) is list
+    assert "Default" in dm.get_models_supported()["models"]
